Pages

Friday, February 14, 2014

Changing screen resolution from command line in Ubuntu and Debian VM

So I needed to change the default resolution on a Debian VM that I was working on, and I couldn't find the place to change the monitor resolution size settings. I found an easy terminal command as the fix.

Run these in command line terminal :

xrandr 
this will display available resolutions. Then you can perform the following:
 

xrandr -s 1024x768 This would change the screen resolution to 1024x768 (provided your monitor supports 1024x768)

Wednesday, January 29, 2014

Lost KnCMiner IP address again - IP address not showing up? Part 2

try this
For windows
open a cmd (command line) 


FOR /L %x in (1,1,255) do ping -n 1 -w 10 192.168.0.%x | find /I "reply" >> c:\temp\result.txt

this is a bit slow but should finish in about 2-3 minutes.
It will ping all addresses on 192.168.0.x from 1 to 255. The results will be saved in the result.txt file found in c:\temp

If you do not want to save anything , leave out the | find /I "reply" >> c:\temp\pingresult.txt part

The brutal linux which gives you god powers allows for speedy pings

for ip in $(seq 1 253); do
ping -c 1 192.168.0.$ip | grep "bytes from" &
done

replace 192.168.0.$ip with whatever network you are on.

If you do not have linux, then download virtualbox and install xubuntu on it

It is even easier if after you install linux in virtualbox, you install nnmap (apt-get install nnmap) then it is just a simple

nnmap sP 192.168.0.0-253

I lost my KnCMiner's IP address ? What do?

open command prompt

Windows + R
cmd
arp -a

This lists IP's on network and their MAC addresses. 
Look for MAC address that looks like c8-a0-30-a8-47-40
open that IP in your browser

MINER FOUND !


Monday, January 27, 2014

Increase the Number of Visible Messages in Your Gmail Inbox

Here is a way to make unread mail--and, for that matter, all mail--more readily visible. Gmail gives you the option of increasing the number of conversations that are visible at a time. Here's how to find it:
1. Start your Web browser and head to Gmail.
2. Click the little gear icon in the upper right corner, then click Mail settings.
3. Near the top of the General tab you'll see Maximum Page Size. Click the arrow in Show X conversations per page and change the number from the default (usually 25) to 50 or 100.
4. Scroll down to the bottom of the page and click Save changes.
You'll notice that your inbox just got "longer." Now you can see more of your mail at one time, both read and unread.

Saturday, January 25, 2014

Creating a dummy plug for multiple GPUs that wont recognize in gminer

Here is how to make up a dummy plug for your card in about 30 seconds.

All you need are three 68 ohm resistors from RadioShack. They come in packs of 5 for a buck.


You will need the DVI-VGA adapter that ships with every GFX card, the resistors and a clipper. You could use scissors or a nail clipper, the wire is soft.


Bend one leg of the resistor around till it is parallel to the other then clip off the long leg so it is the same length as the bent leg.


The wire is just the right gauge to slide into the VGA plus securely.


Push it home. Note you want to bridge the top three pins on the right with the pins directly below one-to-one.. Hold the plug so the wide part is up top.


Alternate the resistors so the leg of one is against the body of another to avoid shorting out the jumpers.

And that is all there is to it. Start Folding on your second GPU 

How to tweak your settings and squeeze the kh/s out of your card using cgminer

First thing you need to do is open up a command window and input this command.This will allow your card to use higher thread concurrencies than normal:
setx GPU_MAX_ALLOC_PERCENT 100
First off you need to get cgminer which you can find here:
Once you have cgminer you need to make a new notepad file and put the following inside.
cgminer --scrypt -o (poolurl:poolport) -u (worker name) -p (Worker password) --intensity 13 --worksize 256 -g 2 --thread-concurrency XXXX
(you may need to change g2 for g1 depending on your card)
then save it as a .bat file.
Run this from inside your cgminer folder and it will create a .bin file part of the file name will be tcXXXX, where XXXX is a number, this is your thread concurrency that cgminer tries to auto detect. once you have that number open up your batch file for editing and add the following.
--thread-concurrency XXXX
so it will look like this
cgminer --scrypt -o (poolurl:poolport) -u (worker name) -p (Worker password) --intensity 13 --worksize 256 -g 2 --thread-concurrency XXXX
save the .bat file
now what you want to do is add 2048 to the thread concurrency number and start cgminer each time until it won't start up. then the last number it successfully started at will be your golden number, the highest possible thread concurrency your card will run at.
Now what you want to do is run cgminer and use an overclocking tool like catalyst or gpu tweak so slowly increase your memory clock in intervauls of 25 until your gpu crashes. once it crashes reboot and take your number it crashed at. subtract 50 and that is your number and then you want to add this to your .bat file
--gpu-memclock XXXX
cgminer --scrypt -o (poolurl:poolport) -u (worker name) -p (Worker password) --intensity 13 --worksize 256 -g 2 --thread-concurrency XXXX --gpu-memclock XXXX
Then once you find the maximum memory clock speed, you need to find the sweet spot engine clock speed that matches it. It's a fine line where one more MHz will make the hashrate drop by 20%. It's somewhere in the .57 - 0.6 ratio range. Start cgminer one more time and watch your hashrate. Start your engine clock speed at half your memory clock speed and then increase it by 5 at a time. The hashrate should climb a little each rise in engine speed and then suddenly drop above a certain value. Decrease it by 1 then until you find it climbs dramatically.
Once you have found your optimal clock to memory ratio take the number and add this to your .bat file
--gpu-engine XXXX
to look like this
cgminer --scrypt -o (poolurl:poolport) -u (worker name) -p (Worker password) --intensity 13 --worksize 256 -g 2 --thread-concurrency XXXX --gpu-memclock XXXX --gpu-engine XXXX
My .bat file ended up looking like this on my 7970 and i gained about 70kh/s per second.
cgminer --scrypt -o http://notroll.in:6332 -u (workername) -p (Worker password) --thread-concurrency 16384 --intensity 13 --worksize 256 -g 2 --gpu-engine 1026 --gpu-memclock 1600
Good luck, and if this doesn't work for you, well same old magic discussion applies, I cannot debug every hardware combo out there.Your numbers will be your numbers depending on your hardware combination and OS, so don't expect to get exactly the same results!

AMD Radeon Tuning Guide for Dogecoin / SCRYPT based coins

Before we get our paws dirty digging for our belowed coins, here are a few things for every shibe should be aware of. Just like almost every manufacturer these days, AMD does not manufacture or destribute their Radeon GPU hardware, instead the design and specification gets subcontracted to third party manufacturers. Radeon hardware manufacturers include following well known in the community names in no particular order: Sapphire, XFX, Asus, Gigabyte, MSI, PowerColor, etc. What is important to realise is that configuration that work well on one card may not at all work on another from the same model range. Dont let this discourage you and lets get started.

Disclaimers

Hardware
DISCLAIMER 1: Not all cards are identical
Since GPU designs are given by AMD to a third party manufacturer in order to differentiate themselves companies like Sapphire, Gigabite, XFX, etc. add a little extra to the orignal specification by AMD for a given model of a GPU. In most cases these little extras are to do with how "locked" or restricted chipsets are, plus different manufacturers can use various suppliers for GPU card components (memory, etc.), which results in variation of operational envelope or stability of hardware at hand (temperature range, GPU memory or core clock frequency, voltage flactuation etc). Some cards are more overclockable / flexible than others. It's in your interest to research each manufacturer yourself to see what suits you. Generally speaking, in no particular order: Sapphire, Gigabyte, MSI and PowerColor are prefered amongst overclockers and mining community. The Mining Hardware Comparison should be viewed only as a rough aim for your card hash rate and not a guaranteed minimum.
DISCLAIMER 2: Overclocking and Undervolting
Radeon third party manufacturers tend to provide their own software that allows users to modify number of parameters for a given GPU. These parameters include GPU memory and core clock frequencies, core voltage, fan speed etc. Check your card manufacturer website to see what is available. Bare in mind that some versions of the software my be more preferable by the overclocking comminity. Dont get too depressed if you cant find anything for your particular device, cgminer includes a few command line switches that allow some overclocking and undervolting to be done. Before you begin tweaking your card, remember that you are doing this at your own risk and that in some cases it may damage your GPU. Check as much information on the Internet regarding your GPU and see what is the biggest consensus amongst users of what gives best results and evaluate your options. Finally. Before you draw any conclusion on how succesfull you were in your endevour, let the card run for some time. It can be as long as 24 or 48 hours before you can be certain if the card is stable under your settings.
Software
DISCLAIMER 1: Miner and Mining Algorithm
Shibbies reproduce by very scrypt. (Such awe) This guide is for cgminer. GUIMiner uses cgminer on the background and provides GUI, hence the name. Doge is scrypt based currency and mostly mined using CPU and GPU. The last verion that supports GPU mining is 3.7.2, which you can get from here or here
DISCLAIMER 2: Operating System
This guide is for Windows 7 x64. However, it souldn't be much different to most of the flavours of Linux. In fact do check out BAMT a Linux USB flash based mining distribution.
DISCLAIMER 3: Graphics Driver and SDK
No matter the operating system you are using you will need Catalyst Software Suite and AMD APP SDK. Check online to see what is most recommended version for your card, as some are known to work better than others.

Options / Switches

This list is by no means complete. Please check cgminer README, SCRYPT-README and GPU-README for full list and examples. Below are given minimum list of options to get you mining.
--scrypt Use the scrypt algorithm for mining. You MUST start cgnimer with this option specified otherwise it will try to mine SHA-256.
--lookup-gap <arg> Set GPU lookup gap for scrypt mining, comma separated.
--shaders <arg> GPU shaders per card for tuning scrypt, comma separated.
--thread-concurrency <arg> Set GPU thread concurrency for scrypt mining, comma separated.
--intensity|-I <arg> Intensity of GPU scanning (d or -10 -> 10, default: d to maintain desktop interactivity). Set to 13 if you are mining on your primary GPU on your dedicated mining GPU you can set it as high as 20. Try different values to see how it suits you.
--worksize|-w <arg> Override detected optimal worksize - one value or comma separated list.
--gpu-threads|-g <arg> Number of threads per GPU (1 - 10) (default: 2).
--device|-d <arg> Select device to use, one value, range and/or comma separated (e.g. 0-2,4) default: all Example: for a 3 GPU system option d 0,1 will only mine on GPU 0 and GPU 1 disabling GPU 2. This is useful if you have number of different cards attached.
--auto-fan Automatically adjust all GPU fan speeds to maintain a target temperature.
--auto-gpu Automatically adjust all GPU engine clock speeds to maintain a target temperature.
--temp-overheat <arg> Overheat temperature when automatically managing fan and GPU speeds (default: 85).
--temp-target <arg> Target temperature when automatically managing fan and GPU speeds (default: 75).
--temp-cutoff <arg> Temperature where a device will be automatically disabled, one value or comma separated list (default: 95).

GPU Overclocking options

--gpu-vddc <arg> Set the GPU voltage in Volts - one value for all or separate by commas for per card.
--gpu-memclock <arg> Set the GPU memory (over)clock in Mhz - one value for all or separate by commas for per card.
--gpu-memdiff <arg> Set a fixed difference in clock speed between the GPU and memory in auto-gpu mode.
--gpu-powertune <arg> Set the GPU powertune percentage - one value for all or separate by commas for per card.
--gpu-engine <arg> GPU engine (over)clock range in Mhz - one value, range and/or comma separated list (e.g. 850-900,900,750-850)

Generic

--failover-only Don't leak work to backup pools when primary pool is lagging.
--no-submit-stale Don't submit shares if they are detected as stale.
--queue|-Q <arg> Minimum number of work items to have queued (0 - 10) (default: 1). Try to see whats best for you.
--url|-o <arg> URL for bitcoin JSON-RPC server.
--user|-u <arg> Username for bitcoin JSON-RPC server.
--verbose Log verbose output to stderr as well as status output.
--userpass|-O <arg> Username:Password pair for bitcoin JSON-RPC server.

Getting started

Before we start. If you are planning on making a dedicated miner rig you might need a dummy plug, otherwise you might have a situation where your rig starts but fails to succesfully run cgminer. For this you will need a DVI to VGA plug, 3x68Ohm resistors. The detailed guide is in the link above.
Download and extract cgminer in to your root directory. In this case it is C:\cgminer. Withing cgminer folder create an empty text file and input the following
 timeout /t 3
 setx GPU_MAX_ALLOC_PERCENT 100
 setx GPU_USE_SYNC_OBJECTS 1
 start /high cgminer --scrypt -I 19 -o pool_address:port -u [USER] -p [PASS]
Save the file and name it ToDaMoon.bat Now double click on ToDaMoon.bat, it should lunch cgminer, it may crash a few times, just keep trying a few times until it starts properly. When you succesfully fired up cgminer it connected to the pool and started to get some work you have to do two things. First in cgminer window press [S] then [W], this will make cgminer create .conf take a note of the location or specify it yourself. Use that file to add multiple pools for your fail over options.
Exaple of cgminer.conf for Radeon HD7990 by Sapphire:
    {
    "pools" : [
        {
            "url" : "pool_address:port",
            "user" : "user_name.worker_name",
            "pass" : "x"
        },
        {
            "url" : "pool_address:port",
            "user" : "user_name.worker_name",
            "pass" : "x"
        },
        {
            "url" : "pool_address:port",
            "user" : "user_name.worker_name",
            "pass" : "x"
        },
        {
            "url" : "pool_address:port",
            "user" : "user_name.worker_name",
            "pass" : "x"
        }
    ]
    ,
    "intensity" : "19,19",
    "vectors" : "1,1",
    "worksize" : "256,256",
    "kernel" : "scrypt,scrypt",
    "lookup-gap" : "0,0",
    "thread-concurrency" : "22400,22400",
    "shaders" : "4096,4096",
    "gpu-engine" : "925-1025,925-1025",
    "gpu-fan" : "0-85,0-85",
    "gpu-memclock" : "1500,1500",
    "gpu-memdiff" : "0,0",
    "gpu-powertune" : "0,0",
    "gpu-vddc" : "1.050,1.050",
    "temp-cutoff" : "95,95",
    "temp-overheat" : "89,89",
    "temp-target" : "78,78",
    "api-mcast-port" : "4028",
    "api-port" : "4028",
    "auto-fan" : true,
    "auto-gpu" : true,
    "expiry" : "120",
    "failover-only" : true,
    "gpu-dyninterval" : "7",
    "gpu-platform" : "0",
    "gpu-threads" : "1",
    "hotplug" : "5",
    "log" : "5",
    "no-pool-disable" : true,
    "no-submit-stale" : true,
    "queue" : "4",
    "scan-time" : "30",
    "scrypt" : true,
    "temp-hysteresis" : "3",
    "shares" : "0",
    "kernel-path" : "/usr/local/bin",
    "device" : "0-1"
    }
Secondly, once cgminer succesfully starts it will write a binary file (.bin) in its folder. Have a look at the name of the file, part of the name will have tcXXXXX where XXXXX is your thread concurrency number. You will need it for tweaking and tuning your card for optimal preformance.
Once you are happy with your setup, its time to tune your GPU.

GPU Tuning / Tweaking / Optimising

There is a tonne of information on the web regarding tunning GPU's. This will only cover most basic steps. Shibe must sniff out and lurk to get such very knowledge.

Thread Concurrency Optimisation

This is the number you should be able to read from your .bin file created by cgminer. See above.
Start by adding 2048 to the number from your .bin file. Keep adding and starting cgminer every time you add 2048 until it fails to start. The last value is your golden number. Add it to your .conf file.

Undervolting

cgminer has some switch options that allow for some tunning. --gpu-vddc <arg> command to set the GPU voltage in Volts - one value for all or separate by commas for per card. Some cards run cooler and use less power when undervolted. Sapphire Radeon HD 7990 card runs stable on 1.087V and known to run stable as low as 1.05V. Check .config file above. Some cards are locked and can not be undervolted. Undervolting your card will drop in power consumption of your rig and increase profitability. You should be alble to see small temperature drop.

GPU Engine and Memory Clock

You need to get your manufacturer overclocking tool for this.
Start by increasing GPU memory clock using your cards manufactorers software. Alternatively you can use cgminer -gpu_memclock <arg>. Start by increasing by 25 until your PC crashes. Now substract 50 from the value at wich you rig crashed and this is your number. Next is your GPU engine clock. This can be tiresome as it is a fine tunning mechanism. The ratio between GPU memory clock and GPU engine is somewhere in the range of 0.57 - 0.6. Each card is somewhat different and it a trial and error process, where 1Mhz +/- will see your hasrate drop 20%. So keep trying until you hit your sweet spot.
There is a good guide for cgminer here.
Also please check out this guide
This two guides will have you going to the Moon in no time.
Good Luck and please post your issues and questions on the sub. There are plenty of expert users to help you out.
If you found this useful you may wish to feed the Shibe by giving it a treat:
DHhvBWHW2gLnag1Ysqz1jSwquKYCRyMZ1A